'use strict';

exports.__esModule = true;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

require('../../../styles/components/pagination-control.css');

var _isNil = require('lodash/isNil');

var _isNil2 = _interopRequireDefault(_isNil);

var _isNumber = require('lodash/isNumber');

var _isNumber2 = _interopRequireDefault(_isNumber);

var _invariant = require('invariant');

var _invariant2 = _interopRequireDefault(_invariant);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var NAV_VERB_TO_INT_MAP = { prev: -1, next: 1 };
var DISABLED_ATTRIBUTES = { tabIndex: -1, disabled: true };
var ENABLED_ATTRIBUTE = { tabIndex: 0 };

var PaginationControl = function (_React$PureComponent) {
  (0, _inherits3['default'])(PaginationControl, _React$PureComponent);

  function PaginationControl(props) {
    (0, _classCallCheck3['default'])(this, PaginationControl);

    var _this = (0, _possibleConstructorReturn3['default'])(this, _React$PureComponent.call(this, props));

    !props.onPageChange ? process.env.NODE_ENV !== 'production' ? (0, _invariant2['default'])(false, '`onPageChange` prop missing') : (0, _invariant2['default'])(false) : void 0;
    !props.page ? process.env.NODE_ENV !== 'production' ? (0, _invariant2['default'])(false, '`page` prop missing') : (0, _invariant2['default'])(false) : void 0;
    _this.gotoFirstPage = _this.gotoFirstPage.bind(_this);
    _this.gotoPrevPage = _this.gotoPrevPage.bind(_this);
    _this.gotoNextPage = _this.gotoNextPage.bind(_this);
    _this.gotoLastPage = _this.gotoLastPage.bind(_this);
    _this.isPageWithinLowerBound = _this.isPageWithinLowerBound.bind(_this);
    _this.isPageWithinUpperBound = _this.isPageWithinUpperBound.bind(_this);
    _this.isValidPage = _this.isValidPage.bind(_this);
    _this.isDisabled = _this.isDisabled.bind(_this);
    _this.handleInputKeyDown = _this.handleInputKeyDown.bind(_this);
    _this.handleUserInput = _this.handleUserInput.bind(_this);
    return _this;
  }

  PaginationControl.prototype.gotoFirstPage = function gotoFirstPage() {
    this.gotoPage(1);
  };

  PaginationControl.prototype.gotoPrevPage = function gotoPrevPage() {
    var page = this.props.page;

    this.gotoPage(page - 1);
  };

  PaginationControl.prototype.gotoNextPage = function gotoNextPage() {
    var page = this.props.page;

    this.gotoPage(page + 1);
  };

  PaginationControl.prototype.gotoLastPage = function gotoLastPage() {
    var totalPages = this.props.totalPages;

    if (!(0, _isNil2['default'])(totalPages)) this.gotoPage(totalPages);
  };

  PaginationControl.prototype.gotoPage = function gotoPage(page) {
    var payload = { page: page };
    if (!(0, _isNumber2['default'])(page)) {
      payload.error = 'Invalid Number';
    } else if (!this.isPageWithinLowerBound(page)) {
      payload.error = 'Number less than lower bound';
    } else if (!this.isPageWithinUpperBound(page)) {
      payload.error = 'Number greater than upper bound';
    }
    this.props.onPageChange(payload);
  };

  PaginationControl.prototype.isPageWithinLowerBound = function isPageWithinLowerBound(page) {
    var firstPage = 1;
    return page >= firstPage;
  };

  PaginationControl.prototype.isPageWithinUpperBound = function isPageWithinUpperBound(page) {
    var totalPages = this.props.totalPages;

    if ((0, _isNil2['default'])(totalPages)) return true;

    return page <= totalPages;
  };

  PaginationControl.prototype.isValidPage = function isValidPage(page) {
    return this.isPageWithinLowerBound(page) && this.isPageWithinUpperBound(page);
  };

  PaginationControl.prototype.isDisabled = function isDisabled(btnType) {
    var _props = this.props,
        disabled = _props.disabled,
        page = _props.page,
        totalPages = _props.totalPages;


    if (disabled) {
      return DISABLED_ATTRIBUTES;
    }

    if (btnType) {
      if (btnType === 'last' && (0, _isNil2['default'])(totalPages)) {
        return DISABLED_ATTRIBUTES;
      }

      var linkedPage = page + (NAV_VERB_TO_INT_MAP[btnType] || 1);
      var invalidPage = !this.isValidPage(linkedPage);
      if (invalidPage) {
        return DISABLED_ATTRIBUTES;
      }
    }

    return ENABLED_ATTRIBUTE;
  };

  PaginationControl.prototype.handleUserInput = function handleUserInput(evt) {
    this.gotoPage(parseInt(evt.target.value, 10));
  };

  PaginationControl.prototype.handleInputKeyDown = function handleInputKeyDown(evt) {
    var ENTER = 13;
    if (evt.keyCode === ENTER) {
      this.handleUserInput(evt);
    }
  };

  PaginationControl.prototype.render = function render() {
    var _props2 = this.props,
        page = _props2.page,
        totalPages = _props2.totalPages;

    var isDisabled = this.isDisabled;

    return _react2['default'].createElement(
      'div',
      { className: 'pagination' },
      _react2['default'].createElement(
        'button',
        (0, _extends3['default'])({ className: 'pagination__button pagination__prev',
          'data-hook': 'pagination-button-first-page',
          onClick: this.gotoFirstPage }, isDisabled('prev')),
        _react2['default'].createElement('i', { className: 'arrow_carrot-2left', 'aria-hidden': 'true' })
      ),
      _react2['default'].createElement(
        'button',
        (0, _extends3['default'])({ className: 'pagination__button pagination__prev',
          'data-hook': 'pagination-button-prev-page',
          onClick: this.gotoPrevPage }, isDisabled('prev')),
        _react2['default'].createElement('i', { className: 'arrow_carrot-left', 'aria-hidden': 'true' })
      ),
      _react2['default'].createElement(
        'div',
        { className: 'pagination__page-number' },
        _react2['default'].createElement(
          'span',
          null,
          'Page'
        ),
        _react2['default'].createElement('input', (0, _extends3['default'])({ className: 'pagination__input', type: 'number', min: '1', max: totalPages,
          key: '' + page, defaultValue: '' + page,
          onBlur: this.handleUserInput, onKeyDown: this.handleInputKeyDown }, isDisabled())),
        _react2['default'].createElement(
          'span',
          null,
          'of'
        ),
        _react2['default'].createElement(
          'span',
          { className: 'pagination__page-total' },
          totalPages || _react2['default'].createElement(
            'em',
            { className: 'pagination__page-number_total-pages-unknown' },
            '...'
          )
        )
      ),
      _react2['default'].createElement(
        'button',
        (0, _extends3['default'])({ className: 'pagination__button pagination__next',
          'data-hook': 'pagination-button-next-page',
          onClick: this.gotoNextPage }, isDisabled('next')),
        _react2['default'].createElement('i', { className: 'arrow_carrot-right', 'aria-hidden': 'true' })
      ),
      _react2['default'].createElement(
        'button',
        (0, _extends3['default'])({ className: 'pagination__button pagination__next',
          'data-hook': 'pagination-button-last-page',
          onClick: this.gotoLastPage }, isDisabled('last')),
        _react2['default'].createElement('i', { className: 'arrow_carrot-2right', 'aria-hidden': 'true' })
      )
    );
  };

  return PaginationControl;
}(_react2['default'].PureComponent);

exports['default'] = PaginationControl;


PaginationControl.propTypes = {
  disabled: _propTypes2['default'].bool,
  /**
   * Called when the control is blurred.
   * @param {Number} page target page number
   */
  onPageChange: _propTypes2['default'].func.isRequired,
  /**
  * Called when the page changes.
  * @param {Number} page target page number
  */
  page: _propTypes2['default'].number,
  totalPages: _propTypes2['default'].number
};
module.exports = exports['default'];
//# sourceMappingURL=PaginationControl.js.map